@@ -293,7 +293,7 @@ distill_highlighting_args <- function(highlight) {
   #
   #   https://github.com/jgm/skylighting/blob/a1d02a0db6260c73aaf04aae2e6e18b569caacdc/skylighting-core/src/Skylighting/Format/HTML.hs#L117-L147
   #
-  default <- pandoc_path_arg(distill_resource("a11y.theme"))
+  default <- pandoc_path_arg(distill_resource("arrow.theme"))
 
   # if it's "rstudio", then use an embedded theme file
   if (identical(highlight, "rstudio")) {
